@@ -19,13 +19,13 @@ for (i in seq_along(nms)) { # (i = 1L)
       paste('Data of', switch(tmp[1L], EXA = 'Example', EXR = 'Exercise'),
             paste(as.numeric(tmp[-1L]), collapse = '.'))
     }, LDS = {
-      paste0('Large Data \\code{', tmp[3L], '} from Chapter ', 
+      paste0('Large Data `', tmp[3L], '` from Chapter ', 
              as.numeric(substr(tmp[2L], start = 2L, stop = 3L)))
     }, REV = {
       paste('Review Exercise', as.numeric(tmp[3L]), 'of Chapter', 
             as.numeric(substr(tmp[2L], start = 2L, stop = 3L)))
     }, stop())),
-    paste0('#\' @description \\code{', nms[i], '}'), 
+    paste0('#\' @description `', nms[i], '`'), 
     paste('#\' @format A \\link[base]{data.frame} with', 
           .row_names_info(ival, type = 2L), 'rows and', length(ival), 'columns'),
     paste0('\'', nms[i], '\''), 
