@@ -1,10 +1,9 @@
 library(DanielBiostatistics10th)
 
 # Page 493, Example 10.3.1
-d1031 = read.csv(system.file('extdata', 'EXA_C10_S03_01.csv', package = 'DanielBiostatistics10th'))
-head(d1031)
-pairs(d1031, main = 'Page 494, Figure 10.3.1')
-summary(mod_1031 <- lm(CDA ~ AGE + EDLEVEL, data = d1031))
+head(EXA_C10_S03_01)
+pairs(EXA_C10_S03_01, main = 'Page 494, Figure 10.3.1')
+summary(mod_1031 <- lm(CDA ~ AGE + EDLEVEL, data = EXA_C10_S03_01))
 
 # Page 502, Example 10.4.1
 # .. see 'Multiple R-squared' (not 'Adjusted R-squared')
@@ -24,11 +23,10 @@ predict(mod_1031, newdata = newd_1031, interval = 'prediction')
 predict(mod_1031, newdata = newd_1031, interval = 'confidence')
 
 # Page 511, Example 10.6.1
-d1061 = read.csv(system.file('extdata', 'EXA_C10_S06_01.csv', package = 'DanielBiostatistics10th'))
-head(d1061)
-pairs(d1061, main = 'Scatter Plot Matrix of Example 10.6.1')
-summary(mod_1061 <- lm(W ~ P + S, data = d1061))
+head(EXA_C10_S06_01)
+pairs(EXA_C10_S06_01, main = 'Scatter Plot Matrix of Example 10.6.1')
+summary(mod_1061 <- lm(W ~ P + S, data = EXA_C10_S06_01))
 confint(mod_1061)
 
 # (optional) Page 515, Example 10.6.2
-psych::partial.r(d1061, x = 2:3, y = 1L)
+psych::partial.r(EXA_C10_S06_01, x = 2:3, y = 1L)
