@@ -16,15 +16,17 @@ anova(m931)
 plot(m931, which = 1, main = 'Page 440, Figure 9.4.8')
 
 # Page 441, Section 9.5
-autoplot(predict_lm(m931), xlab = 'Waist circumference (cm), X', 
-         ylab = 'Deep abdominal AT area (cm2), Y',
-         title = 'Page 422, Figure 9.3.3; Page 442, Figure 9.5.1')
+autoplot(predict_lm(m931)) + labs(
+  xlab = 'Waist circumference (cm), X', 
+  ylab = 'Deep abdominal AT area (cm2), Y',
+  title = 'Page 422, Figure 9.3.3; Page 442, Figure 9.5.1')
 
 # Page 447, Example 9.7.1
 head(EXA_C09_S07_01)
 summary(mod_971 <- lm(CV ~ HEIGHT, data = EXA_C09_S07_01))
-autoplot(predict_lm(mod_971), xlab = 'Height (cm)', ylab = 'Cv (units)', 
-         title = 'Page 449, Figure 9.7.2')
+autoplot(predict_lm(mod_971)) + labs(
+  xlab = 'Height (cm)', ylab = 'Cv (units)', 
+  title = 'Page 449, Figure 9.7.2')
 
 # Page 452, Example 9.7.2
 cor(EXA_C09_S07_01); cor.test(~ CV + HEIGHT, data = EXA_C09_S07_01) 
